# Preamble ----

# **Description ----
# This file replicates the Tables and Figures in the body of  Nomikos and Sambanis  (2019)

# Clear Workspace
rm(list=ls())


# Set your working directory below:
setwd("/Users/williamnomikos/Dropbox/Work/Projects/Audience Costs/JPR Submission/Replication")

# Libraries
library(foreign)
library(arm)
library(sciplot)
library(plotrix)

# **Data ----
exp1<-data.frame(read.dta("exp1.dta"))
exp2<-data.frame(read.dta("exp2.dta"))

# **Functions ----

coef.plot<-function(y,z, row,color){
  temp<-lm(y~z)
  
  temp2<-confint(temp)
  lower<-temp2[2,1]
  upper<-temp2[2,2]
  
  temp3<-confint(temp, level=0.90)
  lower90<-temp3[2,1]
  upper90<-temp3[2,2]
  
  temp2<-summary(temp)$coef
  est<-round(temp2[2,1],2)
  
  
  segments(x0=lower, x1=upper, y0=row,y1=row,lwd=4,col="gray")
  segments(x0=lower90, x1=upper90, y0=row,y1=row,lwd=4)
  points(x=est, y=row,pch=21, bg=color, cex=12)
  text(x=est, y=row, labels=est, cex=2.5)
  
  
}


# Tables ----


# **Table II: Number of respondents by treatment groups (Experiment 1) ----
table(exp1$treat)


# **Table III: Leader approval, by treatment vignette (Experiment 1) ----

table3<-matrix(NA,4,3)

y<-exp1$appyes[exp1$treat==0]
xbar<-mean(y,na.rm=T)
sex <- std.error(y,na.rm=T)
upper<-xbar+1.96*sex
lower<-xbar-1.96*sex
table3[1,]<-round(c(xbar,lower,upper),3)

y<-exp1$appyes[exp1$treat==1]
xbar<-mean(y,na.rm=T)
sex <- std.error(y,na.rm=T)
upper<-xbar+1.96*sex
lower<-xbar-1.96*sex
table3[2,]<-round(c(xbar,lower,upper),3)

y<-exp1$appyes[exp1$treat==3]
xbar<-mean(y,na.rm=T)
sex <- std.error(y,na.rm=T)
upper<-xbar+1.96*sex
lower<-xbar-1.96*sex
table3[3,]<-round(c(xbar,lower,upper),3)

y<-exp1$appyes[exp1$treat==2]
xbar<-mean(y,na.rm=T)
sex <- std.error(y,na.rm=T)
upper<-xbar+1.96*sex
lower<-xbar-1.96*sex
table3[4,]<-round(c(xbar,lower,upper),3)

table3

# **Table IV: Number of respondents by treatment groups (Experiment 2)

table(exp2$treat)

# Figures ----

# ** Figure 1 ----
audcosts<-matrix(NA,3,2)
rownames(audcosts)<-c("Belligerence costs", "Inconsistency costs","Incompetence costs")
audcosts

audcosts[,1]<-c(0.5,0.5,0)
audcosts[,2]<-c(0.2,0.3,0.5)

par(mar = c(5, 5, 2, 2)) 
plot.new()
plot.window(xlim=c(0,2.5), ylim=c(0,1.1))
#axis(2, cex.axis=1)
b<-barplot(audcosts, col=c("white","lightgray","darkgray"), add=T, axes=F)
axis(1, at=c(b[1],b[2]), lab=c("Without incompetence costs", "With incompetence costs"), cex.axis=1)

text(x=c(b[1],b[2]),y=c(0.8,0.3),"Inconsistency costs",cex=1.2)
text(x=c(b[1],b[2]),y=c(0.4,0.1),"Belligerence costs",cex=1.2)
text(x=b[2],y=c(0.8),"Incompetence costs",cex=1.2)

#Save
dev.copy(pdf,"fig_1.pdf", height=6, width=8)
dev.off()



# ** Figure 4a ----

tab.averages<-matrix(NA,2,3)
averages<-round(aggregate(exp2$approval, by=list(exp2$treat), FUN=mean,na.rm=T)[2],2)
tab.averages[1:2,1]<-averages[1:2,]
averages<-round(aggregate(exp2$approval[exp2$outcome==4], by=list(exp2$treat[exp2$outcome==4]), FUN=mean,na.rm=T)[2],2)
tab.averages[1:2,2]<-averages[3:4,]
averages<-round(aggregate(exp2$approval[exp2$outcome==1], by=list(exp2$treat[exp2$outcome==1]), FUN=mean,na.rm=T)[2],2)
tab.averages[1:2,3]<-averages[5:6,]
rownames(tab.averages)<-c("Stay out","Back down")
colnames(tab.averages)<-c("No info","Unlikely success", "Likely success")
tab.averages

bar<-barplot(tab.averages, beside=T,legend.text=T, ylim=c(0,6.5), 
             cex.axis = 1.7, cex.names = 1.7, cex.main=2,
             args.legend=list(x=10,y=6,bty="n", cex=1.5,pt.cex=1, x.intersp=0.2))
text(x=bar, y=tab.averages, labels=tab.averages, pos=3, xpd=NA, cex=1.7)

dev.copy(pdf,"fig_4a.pdf", width=10, height=6) 
dev.off()


# ** Figure 4b ----

#Create coefficient Plot
plot(0,0, ylim=c(4,0), xlim=c(0.1,6.5), type="n",
     xlab="",
     ylab="", 
     yaxt="n",
     cex.axis=2,
     cex.main=2
)
segments(y0=0, y1=5,x0=0, x1=0, lty=2)

text(y=1,x=5,"No info", cex=2.5)
z<-exp2$treat_noinfo
y<-exp2$approval
coef.plot(y,z,row=1,color="white")

text(y=2,x=5,"Low likelihood of success", cex=2)
z<-exp2$treat_low[exp2$outcome==4]
y<-exp2$approval[exp2$outcome==4]
coef.plot(y,z,row=2,color="light gray")

text(y=3,x=5,"High likelihood of success", cex=2)
z<-exp2$treat_high[exp2$outcome==1]
y<-exp2$approval[exp2$outcome==1]
coef.plot(y,z,row=3,color="dark gray")


dev.copy(pdf,"fig_4b.pdf", width=10, height=6) 
dev.off()

